@@ -13,30 +13,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <mate.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include "about-dialog.h"
 
 void about_dialog_open(SensorsApplet *sensors_applet) {
-    gchar *translator;
     const gchar *authors[] = {
         "Alex Murray <murray.alex@gmail.com>",
         "Stefano Karapetsas <stefano@karapetsas.com>",
         NULL
     };
 
-    if (_("Translator") == "Translator") {
-        translator = NULL;
-    } else {
-        translator = g_strdup(_("To translator: Put your name here to show up in the About dialog as the translator"));
-    }
-
     /* Construct the about dialog */
     gtk_show_about_dialog(NULL,
                   "program-name", PACKAGE_NAME, 
@@ -44,14 +39,10 @@ void about_dialog_open(SensorsApplet *sensors_applet) {
                   "copyright", "(C) 2005-2009, Alex Murray <murray.alex@gmail.com>\n(C) 2011, Stefano Karapetsas <stefano@karapetsas.com>",
                   "authors", authors,
                   "documenters", authors,
-                  "translator-credits", translator,
+                  /* To translator: Put your name here to show up in the About dialog as the translator */
+                  "translator-credits", _("translator-credits"),
                   "logo-icon-name", SENSORS_APPLET_ICON,
                   "website", "http://www.mate-desktop.org",
                   NULL);
 
-
-    if (translator != NULL) {
-        g_free(translator);
-    }
-
 }
